@@ -63,7 +63,7 @@
 #'   H_infer
 #'   H
 #'
-#'   H_dt <- sig_fit(V, W, method = "QP", return_class = "data.table")
+#'   H_dt <- sig_fit(V, W, method = "QP", auto_reduce = TRUE, return_class = "data.table")
 #'   H_dt
 #'
 #'   ## Show results
@@ -76,21 +76,21 @@
 #'   show_groups(z)
 #' }
 #'
-# if (requireNamespace("GenSA", quietly = TRUE)) {
-#   H_infer <- sig_fit(V, W, method = "SA")
-#   H_infer
-#   H
-#
-#   H_dt <- sig_fit(V, W, method = "SA", return_class = "data.table")
-#   H_dt
-#
-#   ## Modify arguments to method
-#   sig_fit(V, W, method = "SA", maxit = 10, temperature = 100)
-#
-#   ## Show results
-#   show_sig_fit(H_infer)
-#   show_sig_fit(H_dt)
-# }
+#' # if (requireNamespace("GenSA", quietly = TRUE)) {
+#' #   H_infer <- sig_fit(V, W, method = "SA")
+#' #   H_infer
+#' #   H
+#' #
+#' #   H_dt <- sig_fit(V, W, method = "SA", return_class = "data.table")
+#' #   H_dt
+#' #
+#' #   ## Modify arguments to method
+#' #   sig_fit(V, W, method = "SA", maxit = 10, temperature = 100)
+#' #
+#' #   ## Show results
+#' #   show_sig_fit(H_infer)
+#' #   show_sig_fit(H_dt)
+#' # }
 #' @testexamples
 #' expect_is(H_infer, "matrix")
 #' expect_is(H_dt, "data.table")
@@ -278,18 +278,20 @@ sig_fit <- function(catalogue_matrix,
   #   auto_reduce = auto_reduce,
   #   ...
   # )
-  expo <- purrr::pmap(list(as.data.frame(catalogue_matrix),
-                           rel_threshold,
-                           if (is.null(colnames(catalogue_matrix))) {
-                             NA_character_
-                           } else {
-                             colnames(catalogue_matrix)
-                           } ),
-                      f_fit,
-                      sig_matrix,
-                      type = type,
-                      auto_reduce = auto_reduce,
-                      ...
+  expo <- purrr::pmap(list(
+    as.data.frame(catalogue_matrix),
+    rel_threshold,
+    if (is.null(colnames(catalogue_matrix))) {
+      NA_character_
+    } else {
+      colnames(catalogue_matrix)
+    }
+  ),
+  f_fit,
+  sig_matrix,
+  type = type,
+  auto_reduce = auto_reduce,
+  ...
   )
   send_success("Done.")
 
@@ -391,7 +393,7 @@ decompose_NNLS <- function(x, y, z, sig_matrix, type = "absolute", auto_reduce =
     if (auto_reduce) {
       rec <- (expo %*% t(sig_matrix) * sum(x))[1, ]
       sim <- cosine(rec, x)
-      if (sim < 0.99) {
+      if (sim < 0.95) {
         sim_old <- sim
         # continue to optimize
         send_info("Start optimizing...")
@@ -402,15 +404,17 @@ decompose_NNLS <- function(x, y, z, sig_matrix, type = "absolute", auto_reduce =
           abs_expo <- decompose_NNLS(x, 0, z, sig_matrix_update, type = "absolute")
           rec_update <- (abs_expo %*% t(sig_matrix_update))[1, ]
           sim_update <- cosine(rec_update, x)
-          if (sim_update < sim) {
+          if (sim_update < sim + 0.01) {
             break()
           }
           sim <- sim_update
         }
-        send_success("Stop optimizing at exposure level: ",
-                     i, ", ",
-                     sum(expo_low),
-                     " signatures dropped.")
+        send_success(
+          "Stop optimizing at exposure level: ",
+          i, ", ",
+          sum(expo_low),
+          " signatures dropped."
+        )
         send_info("Cosine similarity with ", round(abs(sim - sim_old), 6), " improved.")
 
         out_expo <- vector("numeric", length = length(expo))
@@ -423,7 +427,6 @@ decompose_NNLS <- function(x, y, z, sig_matrix, type = "absolute", auto_reduce =
         send_success("The cosine similarity is very high, just return result.")
       }
     }
-
   } else {
     expo <- rep(0, ncol(sig_matrix))
   }
@@ -431,9 +434,7 @@ decompose_NNLS <- function(x, y, z, sig_matrix, type = "absolute", auto_reduce =
   return_expo(expo = expo, y, type, total = sum(x))
 }
 
-# m observed turmor profile vector for a single patient/sample, 96 by 1. m is normalized.
 # P is same as sig_matrix
-
 decompose_QP <- function(x, y, z, P, type = "absolute", auto_reduce = FALSE, ...) {
   if (!is.na(z)) send_info("Fitting sample: ", z)
 
@@ -463,7 +464,7 @@ decompose_QP <- function(x, y, z, P, type = "absolute", auto_reduce = FALSE, ...
       sig_matrix <- P
       rec <- (expo %*% t(sig_matrix) * sum(x))[1, ]
       sim <- cosine(rec, x)
-      if (sim < 0.99) {
+      if (sim < 0.95) {
         sim_old <- sim
         # continue to optimize
         send_info("Start optimizing...")
@@ -474,15 +475,17 @@ decompose_QP <- function(x, y, z, P, type = "absolute", auto_reduce = FALSE, ...
           abs_expo <- decompose_QP(x, 0, z, sig_matrix_update, type = "absolute")
           rec_update <- (abs_expo %*% t(sig_matrix_update))[1, ]
           sim_update <- cosine(rec_update, x)
-          if (sim_update < sim) {
+          if (sim_update < sim + 0.01) {
             break()
           }
           sim <- sim_update
         }
-        send_success("Stop optimizing at exposure level: ",
-                     i, ", ",
-                     sum(expo_low),
-                     " signatures dropped.")
+        send_success(
+          "Stop optimizing at exposure level: ",
+          i, ", ",
+          sum(expo_low),
+          " signatures dropped."
+        )
         send_info("Cosine similarity with ", round(abs(sim - sim_old), 6), " improved.")
 
         out_expo <- vector("numeric", length = length(expo))
@@ -495,7 +498,6 @@ decompose_QP <- function(x, y, z, P, type = "absolute", auto_reduce = FALSE, ...
         send_success("The cosine similarity is very high, just return result.")
       }
     }
-
   } else {
     expo <- rep(0, ncol(P))
   }
@@ -533,7 +535,7 @@ decompose_SA <- function(x, y, z, P, type = "absolute", auto_reduce = FALSE, ...
       sig_matrix <- P
       rec <- (expo %*% t(sig_matrix) * sum(x))[1, ]
       sim <- cosine(rec, x)
-      if (sim < 0.99) {
+      if (sim < 0.95) {
         sim_old <- sim
         # continue to optimize
         send_info("Start optimizing...")
@@ -544,15 +546,17 @@ decompose_SA <- function(x, y, z, P, type = "absolute", auto_reduce = FALSE, ...
           abs_expo <- decompose_SA(x, 0, z, sig_matrix_update, type = "absolute")
           rec_update <- (abs_expo %*% t(sig_matrix_update))[1, ]
           sim_update <- cosine(rec_update, x)
-          if (sim_update < sim) {
+          if (sim_update < sim + 0.01) {
             break()
           }
           sim <- sim_update
         }
-        send_success("Stop optimizing at exposure level: ",
-                     i, ", ",
-                     sum(expo_low),
-                     " signatures dropped.")
+        send_success(
+          "Stop optimizing at exposure level: ",
+          i, ", ",
+          sum(expo_low),
+          " signatures dropped."
+        )
         send_info("Cosine similarity with ", round(abs(sim - sim_old), 6), " improved.")
 
         out_expo <- vector("numeric", length = length(expo))
@@ -565,7 +569,6 @@ decompose_SA <- function(x, y, z, P, type = "absolute", auto_reduce = FALSE, ...
         send_success("The cosine similarity is very high, just return result.")
       }
     }
-
   } else {
     expo <- rep(0, ncol(P))
   }
